<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>QMMP について</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>QMMP について</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>翻訳者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>協力者</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>使用許諾契約</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt 製マルティミディアプレイヤー QMMP</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Qt %1 を現在使用しています (コンパイルは Qt %2 で行われました)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 Qmmp Development Team (開発者チーム)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>入力側プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>出力側プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>視覚効果プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>音響効果プラグイン:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>一般プラグイン:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>追加したい URL をここに記入</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="43"/>
        <source>&amp;Add</source>
        <translation>追加(&amp;A)</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="50"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>QMMP 設定</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>プラグイン</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>上級</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>接続</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="757"/>
        <source>Audio</source>
        <translation>音響</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="166"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>メタデータ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="135"/>
        <source>Load metadata from files</source>
        <translation>ファイルからメタデータを読み込む</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="156"/>
        <source>Title format:</source>
        <translation>タイトルの表示形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="142"/>
        <source>Convert underscores to blanks</source>
        <translation>下線記号 _ を空白文字で表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="149"/>
        <source>Convert %20 to blanks</source>
        <translation>%20 を空白文字で表示</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="259"/>
        <source>Preferences</source>
        <translation>プラグイン調整</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="272"/>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="314"/>
        <source>Description</source>
        <translation>プラグイン分類</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="319"/>
        <source>Filename</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="410"/>
        <source>Cover Image Retrieve</source>
        <translation>アルバム表紙画像の取得</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="416"/>
        <source>Use separate image files</source>
        <translation>分割された画像ファイルを利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="426"/>
        <source>Include files:</source>
        <translation>対象ファイル形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="192"/>
        <location filename="../forms/configdialog.ui" line="436"/>
        <source>Exclude files:</source>
        <translation>除外ファイル形式:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="448"/>
        <source>Recursive search depth:</source>
        <translation>再帰検索の深度:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="373"/>
        <source>Playback</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>Continue playback on startup</source>
        <translation>前回終了時の曲から継続して再生</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="386"/>
        <source>Determine file type by content</source>
        <translation>ファイル内容をみて形式を判断</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Directory Scanning Options</source>
        <translation>ディレクトリ探査のオプション</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="182"/>
        <source>Restrict files to:</source>
        <translation>ファイルを限定(拡張子による):</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Miscellaneous</source>
        <translation>その他いろいろ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="211"/>
        <source>Auto-save playlist when modified</source>
        <translation>プレイリストの変更を自動保存</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <source>Look and Feel</source>
        <translation>外観と感触</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Language:</source>
        <translation>言語:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Add files from command line to this playlist:</source>
        <translation>コマンド行からファイルを追加できるプレイリスト:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>URL Dialog</source>
        <translation>URL ダイアログ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="486"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>クリップボードから URL を自動取り込み</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="525"/>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Enable proxy usage</source>
        <translation>代理を利用する</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Proxy host name:</source>
        <translation>代理ホスト名:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="557"/>
        <source>Proxy port:</source>
        <translation>代理ポート:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="570"/>
        <source>Use authentication with proxy</source>
        <translation>代理経由の認証を利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="577"/>
        <source>Proxy user name:</source>
        <translation>代理者ユーザー名:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="590"/>
        <source>Proxy password:</source>
        <translation>代理者パスワード:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="627"/>
        <source>Replay Gain</source>
        <translation>リプレイゲイン</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="633"/>
        <source>Replay Gain mode:</source>
        <translation>リプレイゲインモード:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="650"/>
        <source>Preamp:</source>
        <translation>プリアンプ:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="682"/>
        <location filename="../forms/configdialog.ui" line="727"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Default gain:</source>
        <translation>デフォルトゲイン:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>クリッピング現象を抑えるためピーク情報を使う</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="763"/>
        <source>Buffer size:</source>
        <translation>バッファーサイズ:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="782"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="811"/>
        <source>Use software volume control</source>
        <translation>ソフトウェアによる音量制御を利用</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="818"/>
        <source>16-bit output</source>
        <translation>16ビット出力</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>トラック</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <location filename="../configdialog.cpp" line="287"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="174"/>
        <source>Transports</source>
        <translation>転送</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="184"/>
        <source>Decoders</source>
        <translation>デコーダー</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="194"/>
        <source>Engines</source>
        <translation>エンジン</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="204"/>
        <source>Effects</source>
        <translation>音響効果</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="214"/>
        <source>Visualization</source>
        <translation>視覚効果</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="234"/>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>File Dialogs</source>
        <translation>ファイルダイアログ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="254"/>
        <source>User Interfaces</source>
        <translation>ユーザーインターフェイス</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="286"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="288"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="289"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="290"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="291"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="292"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="294"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="296"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="298"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="308"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;自動判定&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="309"/>
        <source>Brazilian Portuguese</source>
        <translation>ブラジル ポルトガル語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="310"/>
        <source>Chinese Simplified</source>
        <translation>簡体字中国語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="311"/>
        <source>Chinese Traditional</source>
        <translation>繁体字中国語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Czech</source>
        <translation>チェコ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Dutch</source>
        <translation>オランダ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>English</source>
        <translation>英語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>French</source>
        <translation>フランス語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>German</source>
        <translation>ドイツ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>Hebrew</source>
        <translation>ヘブライ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Hungarian</source>
        <translation>ハンガリー語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Italian</source>
        <translation>イタリア語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Japanese</source>
        <translation>日本語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Kazakh</source>
        <translation>カザフ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Lithuanian</source>
        <translation>リトアニア語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="323"/>
        <source>Polish</source>
        <translation>ポーランド語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="324"/>
        <source>Russian</source>
        <translation>ロシア語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="325"/>
        <source>Slovak</source>
        <translation>スロバキア語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="326"/>
        <source>Spanish</source>
        <translation>スペイン語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="327"/>
        <source>Turkish</source>
        <translation>トルコ語</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="328"/>
        <source>Ukrainian</source>
        <translation>ウクライナ語</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation>このファイルが保管されているディレクトリを開く</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation>あらまし</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="111"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="117"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>Track</source>
        <translation>トラック</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="121"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>トラックを指定して即刻再生</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="92"/>
        <location filename="../jumptotrackdialog.cpp" line="145"/>
        <source>Queue</source>
        <translation>キューに入れる</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>再実行</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>この曲に跳ぶ</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="61"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="90"/>
        <location filename="../jumptotrackdialog.cpp" line="143"/>
        <source>Unqueue</source>
        <translation>キューから除く</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation>サポート外のプレイリスト書式です</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="163"/>
        <location filename="../playlistmanager.cpp" line="351"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="42"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation>Qt ファイルダイアログ</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>タグエディター</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>アーティスト:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>アルバム:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>作曲者:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>ジャンル:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation>ディスク番号:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="184"/>
        <location filename="../forms/tageditor.ui" line="222"/>
        <location filename="../forms/tageditor.ui" line="254"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation>年:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation>トラック:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation>記入したタグをファイルに保存してよい</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>テンプレートエディター</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>挿入</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>アルバム</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>トラック番号</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>トラック番号 数字2桁</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>作曲者</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>演奏時間</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>ディスク番号</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>ファイルパス</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>定番</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="134"/>
        <source>All Supported Bitstreams</source>
        <translation>サポート対象のすべてのデジタル録音物</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <source>Select one or more files to open</source>
        <translation>開きたいファイルを選ぶ (複数可)</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="146"/>
        <source>Choose a directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Playlist Files</source>
        <translation>プレイリストファイル</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Open Playlist</source>
        <translation>プレイリストを開く</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="184"/>
        <source>Save Playlist</source>
        <translation>プレイリストを保存</translation>
    </message>
</context>
</TS>
